/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            fileoperations.cc
 *
 *  Thu Aug 26 08:46:21 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "fileoperations.h"

#include <QFile>
#include <QMessageBox>
#include <QSettings>
#include <QFileDialog>

#include <QDialog>
#include <QPushButton>
#include <QLineEdit>
#include <QLabel>
#include <QVBoxLayout>
#include <QHBoxLayout>

class RenameBox : public QDialog {
public:
  RenameBox(QString old) {
    QVBoxLayout *lv = new QVBoxLayout();
    setLayout(lv);
    lv->addWidget(new QLabel(tr("Enter new filename")));
    edt = new QLineEdit(old);
    lv->addWidget(edt);

    QHBoxLayout *lh = new QHBoxLayout();
    lh->addSpacing(0);

    QPushButton *btn = new QPushButton(tr("Ok"));
    connect(btn, SIGNAL(clicked()), this, SLOT(accept()));
    lh->addWidget(btn);
    btn = new QPushButton(tr("Cancel"));
    connect(btn, SIGNAL(clicked()), this, SLOT(reject()));
    lh->addWidget(btn);

    lv->addLayout(lh);
  }

  QString filename() { return edt->text(); }

private:
  QLineEdit *edt;
};

void deleteSelected(ViewerItem *item)
{
  QMessageBox::StandardButton ret =
    QMessageBox::warning(NULL, QObject::tr("Delete file"),
                         QObject::tr("Are you sure you want to delete ") +
                         item->file() + QObject::tr("?"),
                         QMessageBox::Yes | QMessageBox::No,
                         QMessageBox::No);

  if(ret == QMessageBox::No) return;

  item->removeSelf();
  QFile::remove(item->file());
}

void copySelected(ViewerItem *item)
{
  QSettings settings("Aasimon.org", "PC-Show");
  settings.beginGroup("Options");
  QString dst = settings.value("storepath",
                               QObject::tr("c:\\drafts")).toString();
  settings.endGroup();

  dst = QFileDialog::getExistingDirectory(NULL,
                                          QObject::tr("Choose destination"),
                                          dst);
  if(dst == "") return;

  QFile::copy(item->file(), dst + "/" + QFileInfo(item->file()).fileName());
}

void moveSelected(ViewerItem *item)
{
  QSettings settings("Aasimon.org", "PC-Show");
  settings.beginGroup("Options");
  QString dst = settings.value("storepath",
                               QObject::tr("c:\\drafts")).toString();
  settings.endGroup();

  dst = QFileDialog::getExistingDirectory(NULL,
                                          QObject::tr("Choose destination"),
                                          dst);
  if(dst == "") return;

  QFile file(item->file());
  if(file.copy(dst + "/" + QFileInfo(item->file()).fileName())) {
    item->removeSelf();
    QFile::remove(item->file());
  }
}

void saveSelectedAs(ViewerItem *item)
{
  QSettings settings("Aasimon.org", "PC-Show");
  settings.beginGroup("Options");
  QString dst = settings.value("storepath",
                               QObject::tr("c:\\drafts")).toString();
  settings.endGroup();
  
  QString file = QFileDialog::getSaveFileName(NULL,
                                              QObject::tr("Save File"), dst);
  if(file != "") {
    QImage image(item->file());
    image.save(file);
  }
}

void renameSelected(ViewerItem *item)
{
  QSettings settings("Aasimon.org", "PC-Show");
  settings.beginGroup("Options");
  QString dst = settings.value("storepath",
                               QObject::tr("c:\\drafts")).toString();
  settings.endGroup();

  RenameBox renbox(item->file());
  if(renbox.exec() == QDialog::Accepted &&
     renbox.filename() != item->file()) {
    QFile::rename(item->file(), renbox.filename());
    item->updateFilename(renbox.filename());
  }
}
