/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            filewidget.cc
 *
 *  Mon Aug 23 14:51:38 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "filewidget.h"

#include <QHBoxLayout>
#include <QSettings>
#include <QDir>
#include <QDateTime>
#include <QFileInfo>
#include <QTextCodec>

FileWidget::FileWidget()
{
  list = new QTreeWidget(this);
  list->setIconSize(QSize(32, 32));
  list->setSelectionMode(QAbstractItemView::ExtendedSelection);
  list->setSortingEnabled(true);
  list->setRootIsDecorated(false);

  list->setColumnCount(3);
  list->setColumnWidth(0, 38);
  list->setColumnWidth(1, 100);
  list->setColumnWidth(2, 80);
  QStringList labels;
  labels.push_back("");
  labels.push_back(tr("Filename"));
  labels.push_back(tr("Date"));
  list->setHeaderLabels(labels);
  setWidget(list);

  connect(this, SIGNAL(changePath(const QString &)),
          this, SLOT(pathChanged(const QString &)));

  connect(this, SIGNAL(addItemStr(const QString &)),
          this, SLOT(addItem(const QString &)));

  connect(list, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
          this, SLOT(dblClick(QTreeWidgetItem *, int)));
}

void FileWidget::setWatchFile(QString file)
{
  if(!watcher.files().empty()) watcher.removePaths(watcher.files());
  watcher.addPath(file);

  connect(&watcher, SIGNAL(fileChanged(const QString &)),
          this, SLOT(fileChanged(const QString &)),
          Qt::QueuedConnection);

  connect(&dirwatcher, SIGNAL(directoryChanged(const QString &)),
          this, SLOT(pathChanged(const QString &)));

  fileChanged(file); // Trigger initial reading.
}

bool FileWidget::parseFile(const QString &file)
{
  QFile f(file);
  if(!f.open(QIODevice::ReadOnly | QIODevice::Text)) return false;

  QList<QByteArray> data = f.readAll().split(' ');
  if(data.length() < 2) return false;
  path = data.at(0);
  data.removeFirst();
  name = "";

  QTextCodec *codec = QTextCodec::codecForName("CP850");

  QList<QByteArray>::iterator i = data.begin();
  while(i != data.end()) {
    if(i != data.begin()) name += " ";
    name += codec->toUnicode(*i);
    i++;
  }
  while(name.right(1) == "\n") name = name.left(name.length() - 1);
  return true;
}

void FileWidget::fileChanged(const QString &file)
{
  QString oldpath = path;
  QString oldname = name;

  if(parseFile(file)) {
    if(oldpath != path) {
      emit changePath(path);
      if(!dirwatcher.files().empty())
        dirwatcher.removePaths(dirwatcher.directories());
      dirwatcher.addPath(path);
    }
    if(oldname != name) emit changeName(name);
  }
}

void FileWidget::pathChanged(const QString &imgpath)
{
  list->clear();
  QDir dir(imgpath);
  QStringList files = dir.entryList(QDir::Files | QDir::Readable, QDir::Time);

  QStringList::iterator i = files.begin();
  while(i != files.end()) {
    emit addItemStr(*i);
    i++;
  }
}

QStringList FileWidget::selection()
{
  QStringList filenames;

  QList<QTreeWidgetItem *> items = list->selectedItems();
  QList<QTreeWidgetItem *>::iterator i = items.begin();
  while(i != items.end()) {
    filenames.append(path + "/" + (*i)->text(1));
    i++;
  }

  return filenames;
}

void FileWidget::addItem(const QString &file)
{
  QImage image;
  
  if(image.load(path + "/" + file)) {
    image = image.scaled(64, 64, Qt::IgnoreAspectRatio);
    QIcon icon(QPixmap::fromImage(image));

    QTreeWidgetItem *item = new QTreeWidgetItem();
    item->setIcon(0, icon);
    item->setText(1, file);
    QFileInfo info(path + "/" + file);
    item->setText(2, info.created().toString(Qt::SystemLocaleShortDate));
    list->addTopLevelItem(item);
  }

  //  qApp->processEvents();
}

void FileWidget::dblClick(QTreeWidgetItem *item, int)
{
  emit dblClicked(path + "/" + item->text(1));
}
