/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            fullscreenwidget.cc
 *
 *  Tue Aug 24 11:24:00 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "fullscreenwidget.h"

#include <QPaintEvent>
#include <QResizeEvent>
#include <QPainter>
#include <QMouseEvent>
#include <QWheelEvent>
#include <QKeyEvent>
#include <QCursor>

FullscreenWidget::FullscreenWidget(QImage &i)
  : image(i)
{
  scale = 1.0;
  offset = QPoint(0,0);
  delta = QPoint(0,0);
  scrollSpeed = 0.001;
  draging = false;
  setMouseTracking(true);

  setFocusPolicy(Qt::WheelFocus);
  setFocus();
  setCursor(Qt::OpenHandCursor);
  showFullScreen();
  scaled = image;
}

void FullscreenWidget::paintEvent(QPaintEvent *event)
{
  QPainter p(this);
  p.drawImage(QPoint(0,0), scaled, QRect(offset + delta, size()) );
}

void FullscreenWidget::wheelEvent(QWheelEvent *event)
{
  scale += ((double)event->delta()) * scrollSpeed;

  if(scale > 6) scale = 6;
  if(scale < 0.125) scale = 0.125;

  scaled = image.scaled(image.size() * scale,
                        Qt::KeepAspectRatio,
                        Qt::SmoothTransformation);
  repaint();
}

void FullscreenWidget::mouseMoveEvent(QMouseEvent *event)
{
  if(draging) {
    delta = startdrag - event->pos();

    QPoint p = offset + delta;
    if(p.x() < -width() + 10) p.setX(-width() + 10);
    if(p.y() < -height() + 10) p.setY(-height() + 10);
 
    if(p.x() > scaled.width() - 10) p.setX(scaled.width() - 10);
    if(p.y() > scaled.height() - 10) p.setY(scaled.height() - 10);
   
    delta = p - offset;

    repaint();
  }
}

void FullscreenWidget::mousePressEvent(QMouseEvent *event)
{
  startdrag = event->pos();
  draging = true;
  setCursor(Qt::ClosedHandCursor);
}

void FullscreenWidget::mouseReleaseEvent(QMouseEvent *event)
{
  offset = offset + delta;
  delta = QPoint(0,0);
  draging = false;
  setCursor(Qt::OpenHandCursor);
}

void FullscreenWidget::keyPressEvent(QKeyEvent *event)
{
  if(event->key() == Qt::Key_Escape) close();
}

void FullscreenWidget::leaveEvent(QEvent *)
{
  //close();
}
