/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            imagewidget.cc
 *
 *  Tue Aug 24 10:22:06 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "imagewidget.h"

#include <QPaintEvent>
#include <QResizeEvent>
#include <QPainter>

#include "fullscreenwidget.h"

ImageWidget::ImageWidget(const QString &file)
{
  setFile(file);
}

void ImageWidget::setFile(const QString &file)
{
  image.load(file);
  scaled = image.scaled(size(),
                        Qt::KeepAspectRatio,
                        Qt::SmoothTransformation);
  repaint();
}


void ImageWidget::paintEvent(QPaintEvent *)
{
  QPainter p(this);
  p.drawImage((width() - scaled.width()) / 2, 0, scaled);
}

void ImageWidget::resizeEvent(QResizeEvent *event)
{
  scaled = image.scaled(event->size(),
                        Qt::KeepAspectRatio,
                        Qt::SmoothTransformation);
}

void ImageWidget::mouseDoubleClickEvent(QMouseEvent *)
{
  showFullscreen();
}

void ImageWidget::mouseReleaseEvent(QMouseEvent *)
{
  emit selected();
}

void ImageWidget::showFullscreen()
{
  FullscreenWidget *w = new FullscreenWidget(image);
  w->show();
}
