/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            vieweritem.cc
 *
 *  Mon Aug 23 21:02:15 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "vieweritem.h"

#include <QVBoxLayout>
#include <QPushButton>

ViewerItem::ViewerItem(const QString &file)
{
  f = file;
  setAutoFillBackground(true);

  setLayout(new QVBoxLayout());

  img = new ImageWidget(file);
  connect(img, SIGNAL(selected()), this, SLOT(select()));
  layout()->addWidget(img);

  lbl = new QLabel(file);
  lbl->setFixedHeight(20);
  lbl->setAlignment(Qt::AlignHCenter);
  layout()->addWidget(lbl);
  
  QPushButton *btn = new QPushButton(tr("Close"));
  connect(btn, SIGNAL(clicked()), this, SLOT(removeSelf()));
  
  layout()->addWidget(btn);
  setSelected(false);
}

void ViewerItem::updateFilename(const QString &filename)
{
  f = filename;
  img->setFile(filename);
  lbl->setText(filename);
}

QString ViewerItem::file()
{
  return f;
}

void ViewerItem::removeSelf()
{
  emit remove(f);
}

void ViewerItem::showFullscreen()
{
  img->showFullscreen();
}

void ViewerItem::setSelected(bool sel)
{
  this->sel = sel;

  QPalette palette;

  if(sel) {
    palette.setBrush(QPalette::Window, QBrush(QColor(180, 180, 250)));
  } else {
    palette.setBrush(QPalette::Window, QBrush(QColor(230, 230, 230)));
  }

  setPalette(palette);
}

void ViewerItem::select()
{
  emit selected(this);
}
