/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set et sw=2 ts=2: */
/***************************************************************************
 *            viewerwidget.cc
 *
 *  Mon Aug 23 14:58:23 CEST 2010
 *  Copyright 2010 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of PC-Show.
 *
 *  PC-Show is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  PC-Show is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with PC-Show; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#include "viewerwidget.h"

#include <QApplication>
#include <QSettings>

#include "vieweritem.h"

#include <math.h>

ViewerWidget::ViewerWidget()
{
  grid = NULL;
  sel = NULL;
}

void ViewerWidget::updateGrid()
{
  if(grid) delete grid;
  grid = new QGridLayout();
  setLayout(grid);

  int w = (int)ceil(sqrt(items.count()));
  
  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    grid->addWidget(*i, grid->count() / w, grid->count() % w);
    i++;
  }
}

void ViewerWidget::addImage(const QString &file)
{
  QSettings settings("Aasimon.org", "PC-Show");
  settings.beginGroup("Options");
  int max_w = settings.value("mtxcols", "3").toInt();
  int max_h = settings.value("mtxcols", "3").toInt();
  settings.endGroup();

  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    ViewerItem *item = *i;
    if(item->file() == file) {
      items.erase(i);
      items.push_back(item);
      updateGrid();
      return; // We already have this item in the grid.
    }
    i++;
  }
  
  ViewerItem *item = new ViewerItem(file);
  connect(item, SIGNAL(selected(ViewerItem *)),
          this, SLOT(selectionChanged(ViewerItem *)));
  connect(item, SIGNAL(remove(const QString &)),
          this, SLOT(removeImage(const QString &)));
  items.push_back(item);

  if(items.count() > max_w * max_h) delete items.takeFirst();

  updateGrid();
}

void ViewerWidget::removeImage(const QString &file)
{
  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    ViewerItem *item = *i;
    if(item->file() == file) {
      items.erase(i);
      delete item;
      updateGrid();
      return;
    }
    i++;
  }
}

bool ViewerWidget::hasSelection()
{
  return sel != NULL;
}

ViewerItem *ViewerWidget::selected()
{
  return sel;
}

void ViewerWidget::selectionChanged(ViewerItem *item)
{
  sel = item;
  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    ViewerItem *item = *i;
    item->setSelected(item == sel);
    i++;
  }
}

QStringList ViewerWidget::images()
{
  QStringList lst;
  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    ViewerItem *item = *i;
    lst.push_back(item->file());
    i++;
  }
  return lst;
}

void ViewerWidget::clear()
{
  QList<ViewerItem*>::iterator i = items.begin();
  while(i != items.end()) {
    ViewerItem *item = *i;
    items.erase(i);
    delete item;
    updateGrid();
    i++;
  }
}
